@@ -17,12 +17,12 @@
 /*  Include relevant sections of the System header files.              */
 /***********************************************************************/
 #include "my_global.h"
-#if defined(_WIN32)
+#if defined(__WIN__)
 #if defined(__BORLANDC__)
 #define __MFC_COMPAT__                   // To define min/max as macro
 #endif   // __BORLANDC__
 //#include <windows.h>
-#else    // !_WIN32
+#else    // !__WIN__
 #if defined(UNIX)
 #include <errno.h>
 #include <unistd.h>
@@ -30,7 +30,7 @@
 #include <io.h>
 #endif  // !UNIX
 #include <fcntl.h>
-#endif  // !_WIN32
+#endif  // !__WIN__
 
 /***********************************************************************/
 /*  Include application header files:                                  */
@@ -197,11 +197,11 @@ bool MAPFAM::OpenTableFile(PGLOBAL g)
       return true;
       } // endif Memory
 
-#if defined(_WIN32)
+#if defined(__WIN__)
     if (mode != MODE_DELETE) {
-#else   // !_WIN32
+#else   // !__WIN__
     if (mode == MODE_READ) {
-#endif  // !_WIN32
+#endif  // !__WIN__
       CloseFileHandle(hFile);                    // Not used anymore
       hFile = INVALID_HANDLE_VALUE;              // For Fblock
       } // endif Mode
@@ -354,7 +354,8 @@ int MAPFAM::ReadBuffer(PGLOBAL g)
 				if ((rc = GetNext(g)) != RC_OK)
 					return rc;
 
-			case RC_NF:
+      /* falls through */
+      case RC_NF:
         // Skip this record
         if ((rc = SkipRecord(g, false)) != RC_OK)
           return rc;
@@ -468,7 +469,7 @@ int MAPFAM::DeleteRecords(PGLOBAL g, int irc)
       /*****************************************************************/
       n = (int)(Tpos - Memory);
 
-#if defined(_WIN32)
+#if defined(__WIN__)
       DWORD drc = SetFilePointer(fp->Handle, n, NULL, FILE_BEGIN);
 
       if (drc == 0xFFFFFFFF) {
@@ -498,7 +499,7 @@ int MAPFAM::DeleteRecords(PGLOBAL g, int irc)
 #endif   // UNIX
     } // endif Abort
 
-#if defined(_WIN32)
+#if defined(__WIN__)
   CloseHandle(fp->Handle);
 #else    // UNIX
   close(fp->Handle);
